@@ -25,13 +25,13 @@ from apitools.base.protorpclite import protojson
 from apitools.base.py import encoding
 from googlecloudsdk.api_lib.storage import gcs_iam_util
 from googlecloudsdk.api_lib.storage import metadata_util
+from googlecloudsdk.api_lib.storage import storage_util
 from googlecloudsdk.api_lib.util import apis
 from googlecloudsdk.api_lib.util import messages as messages_util
 from googlecloudsdk.command_lib.storage import errors
 from googlecloudsdk.command_lib.storage import storage_url
 from googlecloudsdk.command_lib.storage import user_request_args_factory
 from googlecloudsdk.core import properties
-from googlecloudsdk.core.util import iso_duration
 
 
 def get_bucket_or_object_acl_class(is_bucket=False):
@@ -272,8 +272,12 @@ def process_retention_period(retention_period_string):
 
   messages = apis.GetMessagesModule('storage', 'v1')
   return messages.Bucket.RetentionPolicyValue(
-      retentionPeriod=int(iso_duration.Duration().Parse(
-          retention_period_string).total_seconds))
+      retentionPeriod=int(
+          storage_util.ObjectLockRetentionDuration()
+          .Parse(retention_period_string)
+          .total_seconds
+      )
+  )
 
 
 def process_soft_delete_duration(soft_delete_duration):
