@@ -21,6 +21,7 @@ from __future__ import unicode_literals
 
 import re
 
+from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.container.fleet import gkehub_api_util
 from googlecloudsdk.api_lib.util import apis as core_apis
 from googlecloudsdk.api_lib.util import waiter
@@ -78,7 +79,6 @@ def UpdateMembership(name,
                      membership,
                      update_mask,
                      release_track,
-                     description=None,
                      external_id=None,
                      infra_type=None,
                      clear_labels=False,
@@ -96,7 +96,6 @@ def UpdateMembership(name,
     membership: Membership resource that needs to be updated.
     update_mask: Field names of membership resource to be updated.
     release_track: The release_track used in the gcloud command.
-    description: the value to put in the description field
     external_id: the unique id associated with the cluster, or None if it is not
       available.
     infra_type: The infrastructure type that the cluster is running on
@@ -129,8 +128,7 @@ def UpdateMembership(name,
       request.membership.authority.oidcJwks = oidc_jwks.encode('utf-8')
     else:
       # If oidc_jwks is None, unset membership.oidc_jwks, and let the API
-      # determine when that's an error, not the client, to avoid problems
-      # like cl/339713504 fixed (see unsetting membership.authority, below).
+      # determine when that's an error, not the client.
       request.membership.authority.oidcJwks = None
   else:  # if issuer_url is None, unset membership.authority to disable WI.
     request.membership.authority = None
@@ -154,8 +152,6 @@ def UpdateMembership(name,
     else:
       request.membership.endpoint = endpoint
 
-  if description:
-    request.membership.description = description
   if external_id:
     request.membership.externalId = external_id
   if infra_type == 'on-prem':
@@ -196,7 +192,7 @@ def UpdateMembership(name,
 
 def CreateMembership(project,
                      membership_id,
-                     description,
+                     description=None,
                      location=None,
                      gke_cluster_self_link=None,
                      external_id=None,
@@ -488,22 +484,42 @@ def GenerateConnectAgentManifest(membership_ref,
 # This will get full membership resource name format which should be used most
 # of the time, this is a supported format in resource args, API function
 # request/response objects, etc.
-def ListMembershipsFull():
+def ListMembershipsFull(filter_cluster_missing=False):
   """Lists full Membership names in the fleet for the current project.
 
+  Args:
+    filter_cluster_missing: whether to filter out memberships that are missing
+    a cluster.
   Returns:
     A list of full membership resource names in the fleet in the form
     'projects/*/locations/*/memberships/*'.
     A list of locations which were unreachable.
   """
   client = core_apis.GetClientInstance('gkehub', 'v1beta1')
-  response = client.projects_locations_memberships.List(
-      client.MESSAGES_MODULE.GkehubProjectsLocationsMembershipsListRequest(
-          parent=hub_base.HubCommand.LocationResourceName(location='-')))
+  req = client.MESSAGES_MODULE.GkehubProjectsLocationsMembershipsListRequest(
+      parent=hub_base.HubCommand.LocationResourceName(location='-')
+  )
 
-  return [
-      m.name for m in response.resources if not _ClusterMissing(m.endpoint)
-  ], response.unreachable
+  unreachable = set()
+  def _GetFieldFunc(message, attribute):
+    unreachable.update(message.unreachable)
+    return getattr(message, attribute)
+
+  result = list_pager.YieldFromList(
+      client.projects_locations_memberships,
+      req,
+      field='resources',
+      batch_size_attribute=None,
+      get_field_func=_GetFieldFunc,
+  )
+
+  if filter_cluster_missing:
+    memberships = [
+        m.name for m in result if not _ClusterMissing(m.endpoint)
+    ]
+  else:
+    memberships = [m.name for m in result]
+  return memberships, list(unreachable)
 
 
 def _ClusterMissing(m):
