@@ -41,6 +41,10 @@ def ToV2MembershipFeature(
     v2_membershipfeature.spec.policycontroller = _ToV2PolicyControllerSpec(
         v1_membership_feature_spec.policycontroller
     )
+  elif feature_name == 'configmanagement':
+    v2_membershipfeature.spec.configmanagement = _ToV2ConfigManagementSpec(
+        v1_membership_feature_spec.configmanagement
+    )
   else:
     raise ValueError(
         f'Unsupported membership feature: {v2_membershipfeature.name}'
@@ -48,6 +52,242 @@ def ToV2MembershipFeature(
   return v2_membershipfeature
 
 
+def _ToV2ConfigManagementSpec(
+    v1_configmanagement_spec: message_v1.ConfigManagementMembershipSpec,
+) -> message_v2.ConfigManagementSpec:
+  """Converts a v1alpha ConfigManagementMembershipSpec to a v2alpha ConfigManagementSpec."""
+  if v1_configmanagement_spec is None:
+    return None
+
+  v2_configmanagement_spec = message_v2.ConfigManagementSpec()
+  v2_configmanagement_spec.binauthz = _ToV2ConfigManagementBinauthzConfig(
+      v1_configmanagement_spec.binauthz
+  )
+  v2_configmanagement_spec.cluster = v1_configmanagement_spec.cluster
+  v2_configmanagement_spec.configSync = _ToV2ConfigManagementConfigSync(
+      v1_configmanagement_spec.configSync
+  )
+  v2_configmanagement_spec.hierarchyController = (
+      _ToV2ConfigManagementHierarchyController(
+          v1_configmanagement_spec.hierarchyController
+      )
+  )
+  v2_configmanagement_spec.management = (
+      _ToV2ConfigManagementManagementValueValuesEnum(
+          v1_configmanagement_spec.management
+      )
+  )
+  v2_configmanagement_spec.policyController = (
+      _ToV2ConfigManagementPolicyController(
+          v1_configmanagement_spec.policyController
+      )
+  )
+  v2_configmanagement_spec.version = v1_configmanagement_spec.version
+  return v2_configmanagement_spec
+
+
+def _ToV2ConfigManagementBinauthzConfig(
+    v1_binauthz_config: message_v1.ConfigManagementBinauthzConfig,
+) -> message_v2.ConfigManagementBinauthzConfig:
+  """Converts a v1alpha ConfigManagementBinauthzConfig to a v2alpha ConfigManagementBinauthzConfig."""
+  if v1_binauthz_config is None:
+    return None
+
+  v2_binauthz_config = message_v2.ConfigManagementBinauthzConfig()
+  v2_binauthz_config.enabled = v1_binauthz_config.enabled
+  return v2_binauthz_config
+
+
+def _ToV2ConfigManagementConfigSync(
+    v1_configsync: message_v1.ConfigManagementConfigSync,
+) -> message_v2.ConfigManagementConfigSync:
+  """Converts a v1alpha ConfigManagementConfigSync to a v2alpha ConfigManagementConfigSync."""
+  if v1_configsync is None:
+    return None
+
+  v2_configsync = message_v2.ConfigManagementConfigSync()
+  v2_configsync.allowVerticalScale = v1_configsync.allowVerticalScale
+  v2_configsync.enabled = v1_configsync.enabled
+  v2_configsync.git = _ToV2ConfigManagementGitConfig(v1_configsync.git)
+  v2_configsync.metricsGcpServiceAccountEmail = (
+      v1_configsync.metricsGcpServiceAccountEmail
+  )
+  v2_configsync.oci = _ToV2ConfigManagementOciConfig(v1_configsync.oci)
+  v2_configsync.preventDrift = v1_configsync.preventDrift
+  v2_configsync.sourceFormat = v1_configsync.sourceFormat
+  return v2_configsync
+
+
+def _ToV2ConfigManagementGitConfig(
+    v1_git_config: message_v1.ConfigManagementGitConfig,
+) -> message_v2.ConfigManagementGitConfig:
+  """Converts a v1alpha ConfigManagementGitConfig to a v2alpha ConfigManagementGitConfig."""
+  if v1_git_config is None:
+    return None
+
+  v2_git_config = message_v2.ConfigManagementGitConfig()
+  v2_git_config.gcpServiceAccountEmail = v1_git_config.gcpServiceAccountEmail
+  v2_git_config.httpsProxy = v1_git_config.httpsProxy
+  v2_git_config.policyDir = v1_git_config.policyDir
+  v2_git_config.secretType = v1_git_config.secretType
+  v2_git_config.syncBranch = v1_git_config.syncBranch
+  v2_git_config.syncRepo = v1_git_config.syncRepo
+  v2_git_config.syncRev = v1_git_config.syncRev
+  v2_git_config.syncWaitSecs = v1_git_config.syncWaitSecs
+  return v2_git_config
+
+
+def _ToV2ConfigManagementOciConfig(
+    v1_oci_config: message_v1.ConfigManagementOciConfig,
+) -> message_v2.ConfigManagementOciConfig:
+  """Converts a v1alpha ConfigManagementOciConfig to a v2alpha ConfigManagementOciConfig."""
+  if v1_oci_config is None:
+    return None
+
+  v2_oci_config = message_v2.ConfigManagementOciConfig()
+  v2_oci_config.gcpServiceAccountEmail = v1_oci_config.gcpServiceAccountEmail
+  v2_oci_config.policyDir = v1_oci_config.policyDir
+  v2_oci_config.secretType = v1_oci_config.secretType
+  v2_oci_config.syncRepo = v1_oci_config.syncRepo
+  v2_oci_config.syncWaitSecs = v1_oci_config.syncWaitSecs
+  return v2_oci_config
+
+
+def _ToV2ConfigManagementHierarchyController(
+    v1_hierarchy_controller: message_v1.ConfigManagementHierarchyControllerConfig,
+) -> message_v2.ConfigManagementHierarchyControllerConfig:
+  """Converts a v1alpha ConfigManagementHierarchyController to a v2alpha ConfigManagementHierarchyController."""
+  if v1_hierarchy_controller is None:
+    return None
+
+  v2_hierarchy_controller = (
+      message_v2.ConfigManagementHierarchyControllerConfig()
+  )
+  v2_hierarchy_controller.enableHierarchicalResourceQuota = (
+      v1_hierarchy_controller.enableHierarchicalResourceQuota
+  )
+  v2_hierarchy_controller.enablePodTreeLabels = (
+      v1_hierarchy_controller.enablePodTreeLabels
+  )
+  v2_hierarchy_controller.enabled = v1_hierarchy_controller.enabled
+  return v2_hierarchy_controller
+
+
+def _ToV2ConfigManagementManagementValueValuesEnum(
+    v1_management: message_v1.ConfigManagementMembershipSpec.ManagementValueValuesEnum,
+) -> message_v2.ConfigManagementSpec.ManagementValueValuesEnum:
+  """Converts a v1alpha ConfigManagementMembershipSpec.ManagementValueValuesEnum to a v2alpha ConfigManagementManagementValueValuesEnum."""
+  if v1_management is None:
+    return None
+
+  if (
+      v1_management
+      is message_v1.ConfigManagementMembershipSpec.ManagementValueValuesEnum.MANAGEMENT_UNSPECIFIED
+  ):
+    return (
+        message_v2.ConfigManagementSpec.ManagementValueValuesEnum.MANAGEMENT_UNSPECIFIED
+    )
+  elif (
+      v1_management
+      is message_v1.ConfigManagementMembershipSpec.ManagementValueValuesEnum.MANAGEMENT_AUTOMATIC
+  ):
+    return (
+        message_v2.ConfigManagementSpec.ManagementValueValuesEnum.MANAGEMENT_AUTOMATIC
+    )
+  elif (
+      v1_management
+      is message_v1.ConfigManagementMembershipSpec.ManagementValueValuesEnum.MANAGEMENT_MANUAL
+  ):
+    return (
+        message_v2.ConfigManagementSpec.ManagementValueValuesEnum.MANAGEMENT_MANUAL
+    )
+  else:
+    raise ValueError(f'Unsupported management value: {v1_management}')
+
+
+def _ToV2ConfigManagementPolicyController(
+    v1_policycontroller: message_v1.ConfigManagementPolicyController,
+) -> message_v2.ConfigManagementPolicyController:
+  """Converts a v1alpha ConfigManagementPolicyController to a v2alpha ConfigManagementPolicyController."""
+  if v1_policycontroller is None:
+    return None
+
+  v2_policycontroller = message_v2.ConfigManagementPolicyController()
+  v2_policycontroller.auditIntervalSeconds = (
+      v1_policycontroller.auditIntervalSeconds
+  )
+  v2_policycontroller.enabled = v1_policycontroller.enabled
+  v2_policycontroller.exemptableNamespaces = (
+      v1_policycontroller.exemptableNamespaces
+  )
+  v2_policycontroller.logDeniesEnabled = v1_policycontroller.logDeniesEnabled
+  v2_policycontroller.monitoring = (
+      _ToV2ConfigManagementPolicyControllerMonitoring(
+          v1_policycontroller.monitoring
+      )
+  )
+  v2_policycontroller.mutationEnabled = v1_policycontroller.mutationEnabled
+  v2_policycontroller.referentialRulesEnabled = (
+      v1_policycontroller.referentialRulesEnabled
+  )
+  v2_policycontroller.templateLibraryInstalled = (
+      v1_policycontroller.templateLibraryInstalled
+  )
+  v2_policycontroller.updateTime = v1_policycontroller.updateTime
+  return v2_policycontroller
+
+
+def _ToV2ConfigManagementPolicyControllerMonitoring(
+    v1_monitoring: message_v1.ConfigManagementPolicyControllerMonitoring,
+) -> message_v2.ConfigManagementPolicyControllerMonitoring:
+  """Converts a v1alpha ConfigManagementPolicyControllerMonitoring to a v2alpha ConfigManagementPolicyControllerMonitoring."""
+  if v1_monitoring is None:
+    return None
+
+  v2_monitoring = message_v2.ConfigManagementPolicyControllerMonitoring()
+  v2_monitoring.backends = [
+      _ToV2ConfigManagementPolicyControllerMonitoringBackendsValueListEntryValuesEnum(
+          backend
+      )
+      for backend in v1_monitoring.backends
+  ]
+  return v2_monitoring
+
+
+def _ToV2ConfigManagementPolicyControllerMonitoringBackendsValueListEntryValuesEnum(
+    v1_monitoring_backend: message_v1.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum,
+) -> (
+    message_v2.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum
+):
+  """Converts a v1alpha ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum to a v2alpha ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum."""
+  if v1_monitoring_backend is None:
+    return None
+
+  if (
+      v1_monitoring_backend
+      is message_v1.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.MONITORING_BACKEND_UNSPECIFIED
+  ):
+    return (
+        message_v2.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.MONITORING_BACKEND_UNSPECIFIED
+    )
+  elif (
+      v1_monitoring_backend
+      is message_v1.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.PROMETHEUS
+  ):
+    return (
+        message_v2.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.PROMETHEUS
+    )
+  elif (
+      v1_monitoring_backend
+      is message_v1.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.CLOUD_MONITORING
+  ):
+    return (
+        message_v2.ConfigManagementPolicyControllerMonitoring.BackendsValueListEntryValuesEnum.CLOUD_MONITORING
+    )
+  else:
+    raise ValueError(f'Unsupported monitoring backend: {v1_monitoring_backend}')
+
+
 def _ToV2Origin(
     v1_origin: message_v1.Origin,
 ) -> message_v2.Origin:
@@ -64,6 +304,9 @@ def _ToV2OriginTypeValueValuesEnum(
     v1_origin_type: message_v1.Origin.TypeValueValuesEnum,
 ) -> message_v2.Origin.TypeValueValuesEnum:
   """Converts a v1alpha OriginTypeValueValuesEnum to a v2alpha OriginTypeValueValuesEnum."""
+  if v1_origin_type is None:
+    return None
+
   if (
       v1_origin_type
       is message_v1.Origin.TypeValueValuesEnum.TYPE_UNSPECIFIED
@@ -159,6 +402,9 @@ def _ToV2InstallSpecValueValuesEnum(
     v1_install_spec_value: message_v1.PolicyControllerHubConfig.InstallSpecValueValuesEnum,
 ) -> message_v2.PolicyControllerHubConfig.InstallSpecValueValuesEnum:
   """Converts a v1alpha InstallSpecValueValuesEnum to a v2alpha InstallSpecValueValuesEnum."""
+  if v1_install_spec_value is None:
+    return None
+
   if (
       v1_install_spec_value
       is message_v1.PolicyControllerHubConfig.InstallSpecValueValuesEnum.INSTALL_SPEC_UNSPECIFIED
@@ -218,6 +464,9 @@ def _ToV2MonitoringBackend(
     message_v2.PolicyControllerMonitoringConfig.BackendsValueListEntryValuesEnum
 ):
   """Converts a v1alpha MonitoringBackend to a v2alpha MonitoringBackend."""
+  if v1_monitoring_backend is None:
+    return None
+
   if (
       v1_monitoring_backend
       is message_v1.PolicyControllerMonitoringConfig.BackendsValueListEntryValuesEnum.MONITORING_BACKEND_UNSPECIFIED
@@ -312,6 +561,9 @@ def _ToV2InstallationValueValuesEnum(
     message_v2.PolicyControllerTemplateLibraryConfig.InstallationValueValuesEnum
 ):
   """Converts a v1alpha InstallationValueValuesEnum to a v2alpha InstallationValueValuesEnum."""
+  if v1_installation_value is None:
+    return None
+
   if (
       v1_installation_value
       is message_v1.PolicyControllerTemplateLibraryConfig.InstallationValueValuesEnum.INSTALLATION_UNSPECIFIED
@@ -420,6 +672,9 @@ def _ToV2PodAffinity(
     message_v2.PolicyControllerPolicyControllerDeploymentConfig.PodAffinityValueValuesEnum
 ):
   """Converts a v1alpha PodAffinity to a v2alpha PodAffinity."""
+  if v1_pod_affinity is None:
+    return None
+
   if (
       v1_pod_affinity
       is message_v1.PolicyControllerPolicyControllerDeploymentConfig.PodAffinityValueValuesEnum.AFFINITY_UNSPECIFIED
