@@ -126,6 +126,7 @@ def _Destination(trigger):
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class List(base.ListCommand):
   """List Eventarc triggers."""
 
@@ -153,24 +154,3 @@ class List(base.ListCommand):
     args.CONCEPTS.project.Parse()
     location_ref = args.CONCEPTS.location.Parse()
     return client.List(location_ref, args.limit, args.page_size)
-
-
-@base.Deprecate(
-    is_removed=True,
-    warning=(
-        'This command is deprecated. '
-        'Please use `gcloud eventarc triggers list` instead.'
-    ),
-    error=(
-        'This command has been removed. '
-        'Please use `gcloud eventarc triggers list` instead.'
-    ),
-)
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
-class ListBeta(List):
-  """List Eventarc triggers."""
-
-  @staticmethod
-  def Args(parser):
-    List.Args(parser)
-    parser.display_info.AddFormat(_FORMAT_BETA)
